errors

package
v0.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsNotFound

func IsNotFound(err error) bool

Types

type ErrorWithStatusCode

type ErrorWithStatusCode struct {
	Message    string
	StatusCode int
}

default error is internal service error at handler level if error has different status code use ErrorWithStatusCode

func (*ErrorWithStatusCode) Error

func (e *ErrorWithStatusCode) Error() string

Jump to