Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckFFmpegAvailable ¶
func CheckFFmpegAvailable() error
func SanitizeImage ¶
func SanitizeImage(pendingFile *domain.PendingFile, maxDecodedSize int64) (*domain.SanitizedImage, error)
func SanitizeVideo ¶
func SanitizeVideo(pendingFile *domain.PendingFile, thumbMaxSize int) (*domain.SanitizedVideo, error)
SanitizeVideo sanitizes a video file by stripping metadata and extracting a scaled thumbnail, both in a single ffmpeg invocation. thumbMaxSize is the maximum dimension (px) for the thumbnail. Returns a SanitizedVideo with path to temp file on disk (caller must move/delete it).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.