Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateThumbnail ¶
GenerateThumbnail creates a thumbnail of the given image with a maximum size. It maintains the aspect ratio and returns a new image that fits within maxSize x maxSize.
Types ¶
type BoardNameValidator ¶
func New ¶
func New(cfg *config.Public) *BoardNameValidator
func (*BoardNameValidator) Name ¶
func (e *BoardNameValidator) Name(name string) error
func (*BoardNameValidator) ShortName ¶
func (e *BoardNameValidator) ShortName(name string) error
type MessageValidator ¶
func (*MessageValidator) PendingFiles ¶
func (e *MessageValidator) PendingFiles(files []*domain.PendingFile) error
PendingFiles checks if pending files meet the configured constraints
func (*MessageValidator) Text ¶
func (e *MessageValidator) Text(text string) error
type PasswordValidator ¶
func (*PasswordValidator) Password ¶
func (v *PasswordValidator) Password(password string) error
type ThreadTitleValidator ¶
func (*ThreadTitleValidator) Title ¶
func (e *ThreadTitleValidator) Title(name string) error
Click to show internal directories.
Click to hide internal directories.