Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsNotFound ¶
Types ¶
type ErrorWithStatusCode ¶
default error is internal service error at handler level if error has different status code use ErrorWithStatusCode
func (*ErrorWithStatusCode) Error ¶
func (e *ErrorWithStatusCode) Error() string
Click to show internal directories.
Click to hide internal directories.